{% load i18n %}

{% for reg in registrations %}
<a class="btn btn-default btn-xs" href="{% url 'leprikon:registration_list' %}#{{ reg.slug }}">
    {% blocktrans with participant=reg.participant.full_name %}{{ participant }} already registered{% endblocktrans %}
</a>
{% endfor %}

{% if subject.registration_allowed %}
    <a href="{{ registration_url }}" class="btn btn-primary btn-xs">
        {% trans 'register' %}
    </a>
{% else %}
    {% trans 'Registering is currently not allowed.' %}
{% endif %}
