{% load sekizai_tags %}

{% addtoblock "css" %}
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-multiselect/0.9.13/css/bootstrap-multiselect.css" integrity="sha384-l1tju+TyzPCuWXt+knuFYVhe2ZnnEm0/t9T8BmqNedtIBYj1fmsYrIAap4MU2amm" crossorigin="anonymous"/>
{% endaddtoblock %}

{% addtoblock "js" %}
<script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-multiselect/0.9.13/js/bootstrap-multiselect.min.js" integrity="sha384-2q+7Pk3OSOseTKfNi/t8mZzYRIovdg+nfXYeKmmnivkyD+nxosintmGKX7SWcrOG" crossorigin="anonymous"></script>
{% endaddtoblock %}

